@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Software::License::GPL_1;
 {
-  $Software::License::GPL_1::VERSION = '0.103003';
+  $Software::License::GPL_1::VERSION = '0.103005';
 }
 use base 'Software::License';
 # ABSTRACT: GNU General Public License, Version 1
@@ -14,7 +14,6 @@ sub meta2_name { 'gpl_1' }
 
 1;
 
-
 =pod
 
 =head1 NAME
@@ -23,7 +22,7 @@ Software::License::GPL_1 - GNU General Public License, Version 1
 
 =head1 VERSION
 
-version 0.103003
+version 0.103005
 
 =head1 AUTHOR
 
@@ -31,21 +30,20 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo Signes.
+This software is copyright (c) 2012 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
 __DATA__
 __LICENSE__
                     GNU GENERAL PUBLIC LICENSE
                      Version 1, February 1989
 
  Copyright (C) 1989 Free Software Foundation, Inc.
-                    51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ 51 Franklin St, Suite 500, Boston, MA  02110-1335  USA
 
  Everyone is permitted to copy and distribute verbatim copies
  of this license document, but changing it is not allowed.
