@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Software::LicenseUtils;
 {
-  $Software::LicenseUtils::VERSION = '0.103004';
+  $Software::LicenseUtils::VERSION = '0.103005';
 }
 # ABSTRACT: little useful bits of code for licensey things
 
@@ -79,7 +79,7 @@ my %meta_keys = (
   bsd          => 'BSD',
   gpl          => [ map { "GPL_$_" } qw(1 2 3) ],
   mit          => 'MIT',
-  mozilla      => [ map { "Mozilla_$_" } qw(1_0 1_1) ],
+  mozilla      => [ map { "Mozilla_$_" } qw(1_0 1_1 2_0) ],
 );
 
 
@@ -99,6 +99,7 @@ sub guess_license_from_meta {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -107,7 +108,7 @@ Software::LicenseUtils - little useful bits of code for licensey things
 
 =head1 VERSION
 
-version 0.103004
+version 0.103005
 
 =head1 METHODS
 
@@ -135,10 +136,9 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo Signes.
+This software is copyright (c) 2012 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
